==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebGridKeydownEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebGridKeydownEventArgsDetailDescription } from "./WebGridKeydownEventArgsDetailDescription";
/**
 * @hidden
 */
var WebGridKeydownEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGridKeydownEventArgsDetailDescriptionMetadata, _super);
    function WebGridKeydownEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridKeydownEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebGridKeydownEventArgsDetailDescriptionMetadata.a == null) {
            WebGridKeydownEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridKeydownEventArgsDetailDescriptionMetadata.c(WebGridKeydownEventArgsDetailDescriptionMetadata.a);
        }
        if (a.j(WebGridKeydownEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGridKeydownEventArgsDetailDescriptionMetadata.a);
    };
    WebGridKeydownEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:GridKeydownEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("TargetType", "ExportedType:string:GridKeydownTargetType");
        a.item("TargetType@names", "DataCell;SummaryCell;GroupRow;HierarchicalRow;HeaderCell;MasterDetailRow");
        a.item("Target", "Unknown");
        a.item("Cancel", "Boolean");
    };
    WebGridKeydownEventArgsDetailDescriptionMetadata.d = function (a) {
        WebGridKeydownEventArgsDetailDescriptionMetadata.b(a);
        a.aa("WebGridKeydownEventArgsDetail", function () { return new WebGridKeydownEventArgsDetailDescription(); });
        a.z("WebGridKeydownEventArgsDetail", WebGridKeydownEventArgsDetailDescriptionMetadata.a);
    };
    WebGridKeydownEventArgsDetailDescriptionMetadata.$t = markType(WebGridKeydownEventArgsDetailDescriptionMetadata, 'WebGridKeydownEventArgsDetailDescriptionMetadata');
    WebGridKeydownEventArgsDetailDescriptionMetadata.a = null;
    return WebGridKeydownEventArgsDetailDescriptionMetadata;
}(Base));
export { WebGridKeydownEventArgsDetailDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebGridKeydownEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebGridKeydownEventArgsDetailDescription } from "./WebGridKeydownEventArgsDetailDescription";
/**
 * @hidden
 */
var WebGridKeydownEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGridKeydownEventArgsDetailDescriptionMetadata, _super);
    function WebGridKeydownEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridKeydownEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebGridKeydownEventArgsDetailDescriptionMetadata.a == null) {
            WebGridKeydownEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridKeydownEventArgsDetailDescriptionMetadata.c(WebGridKeydownEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebGridKeydownEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGridKeydownEventArgsDetailDescriptionMetadata.a);
    };
    WebGridKeydownEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:GridKeydownEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("TargetType", "ExportedType:string:GridKeydownTargetType");
        a.item("TargetType@stringUnion", "WebComponents;React");
        a.item("TargetType@names", "DataCell;SummaryCell;GroupRow;HierarchicalRow;HeaderCell;MasterDetailRow");
        a.item("Target", "Unknown");
        a.item("Cancel", "Boolean");
    };
    WebGridKeydownEventArgsDetailDescriptionMetadata.d = function (a) {
        WebGridKeydownEventArgsDetailDescriptionMetadata.b(a);
        a.ac("WebGridKeydownEventArgsDetail", function () { return new WebGridKeydownEventArgsDetailDescription(); });
        a.ab("WebGridKeydownEventArgsDetail", WebGridKeydownEventArgsDetailDescriptionMetadata.a);
    };
    WebGridKeydownEventArgsDetailDescriptionMetadata.$t = markType(WebGridKeydownEventArgsDetailDescriptionMetadata, 'WebGridKeydownEventArgsDetailDescriptionMetadata');
    WebGridKeydownEventArgsDetailDescriptionMetadata.a = null;
    return WebGridKeydownEventArgsDetailDescriptionMetadata;
}(Base));
export { WebGridKeydownEventArgsDetailDescriptionMetadata };
